==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TileGeneratorMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { TileGeneratorMapImageryDescription } from "./TileGeneratorMapImageryDescription";
/**
 * @hidden
 */
var TileGeneratorMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TileGeneratorMapImageryDescriptionMetadata, _super);
    function TileGeneratorMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TileGeneratorMapImageryDescriptionMetadata.b = function (a) {
        if (TileGeneratorMapImageryDescriptionMetadata.a == null) {
            TileGeneratorMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TileGeneratorMapImageryDescriptionMetadata.c(TileGeneratorMapImageryDescriptionMetadata.a);
        }
        if (a.k(TileGeneratorMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.ab(TileGeneratorMapImageryDescriptionMetadata.a);
    };
    TileGeneratorMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("TileGenerator", "ExportedType");
    };
    TileGeneratorMapImageryDescriptionMetadata.d = function (a) {
        TileGeneratorMapImageryDescriptionMetadata.b(a);
        a.ad("TileGeneratorMapImagery", function () { return new TileGeneratorMapImageryDescription(); });
        a.ac("TileGeneratorMapImagery", TileGeneratorMapImageryDescriptionMetadata.a);
    };
    TileGeneratorMapImageryDescriptionMetadata.$t = markType(TileGeneratorMapImageryDescriptionMetadata, 'TileGeneratorMapImageryDescriptionMetadata');
    TileGeneratorMapImageryDescriptionMetadata.a = null;
    return TileGeneratorMapImageryDescriptionMetadata;
}(Base));
export { TileGeneratorMapImageryDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/TileGeneratorMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { TileGeneratorMapImageryDescription } from "./TileGeneratorMapImageryDescription";
/**
 * @hidden
 */
var TileGeneratorMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TileGeneratorMapImageryDescriptionMetadata, _super);
    function TileGeneratorMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TileGeneratorMapImageryDescriptionMetadata.b = function (a) {
        if (TileGeneratorMapImageryDescriptionMetadata.a == null) {
            TileGeneratorMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TileGeneratorMapImageryDescriptionMetadata.c(TileGeneratorMapImageryDescriptionMetadata.a);
        }
        if (a.k(TileGeneratorMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.ac(TileGeneratorMapImageryDescriptionMetadata.a);
    };
    TileGeneratorMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("TileGenerator", "ExportedType");
    };
    TileGeneratorMapImageryDescriptionMetadata.d = function (a) {
        TileGeneratorMapImageryDescriptionMetadata.b(a);
        a.ae("TileGeneratorMapImagery", function () { return new TileGeneratorMapImageryDescription(); });
        a.ad("TileGeneratorMapImagery", TileGeneratorMapImageryDescriptionMetadata.a);
    };
    TileGeneratorMapImageryDescriptionMetadata.$t = markType(TileGeneratorMapImageryDescriptionMetadata, 'TileGeneratorMapImageryDescriptionMetadata');
    TileGeneratorMapImageryDescriptionMetadata.a = null;
    return TileGeneratorMapImageryDescriptionMetadata;
}(Base));
export { TileGeneratorMapImageryDescriptionMetadata };
